summaryrefslogtreecommitdiffstats
path: root/net/http/http_transaction.h
diff options
context:
space:
mode:
authorbengr@chromium.org <bengr@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-07-01 21:20:20 +0000
committerbengr@chromium.org <bengr@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-07-01 21:20:20 +0000
commit1252d42fbf09049ce7c0a8812e0c450a62657c61 (patch)
tree9c566616e8fd035a7ed72b93f6911c9b5a6bb9d0 /net/http/http_transaction.h
parent2c69b85f1d66c0bc0bdcd6248bf9b7fac9aad7f6 (diff)
downloadchromium_src-1252d42fbf09049ce7c0a8812e0c450a62657c61.zip
chromium_src-1252d42fbf09049ce7c0a8812e0c450a62657c61.tar.gz
chromium_src-1252d42fbf09049ce7c0a8812e0c450a62657c61.tar.bz2
Add header pointer to BeforeProxyHeadersSentCallback
This is needed because the higher layers, e.g., UrlRequestHttpJob do not always have a pointer to the request headers that the HttpNetworkTransaction will actually send. Note that the old code could also pass the wrong headers if redirects resulted in no longer going through the proxy. BUG=345907 Review URL: https://codereview.chromium.org/360113004 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@280885 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'net/http/http_transaction.h')
-rw-r--r--net/http/http_transaction.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/net/http/http_transaction.h b/net/http/http_transaction.h
index db8ed52..52b3c97 100644
--- a/net/http/http_transaction.h
+++ b/net/http/http_transaction.h
@@ -36,9 +36,11 @@ class NET_EXPORT_PRIVATE HttpTransaction {
// Provides an opportunity to add proxy-specific request headers. Called after
// it is determined that a proxy is being used and before the request headers
// are sent. |proxy_info| contains information about the proxy being used.
typedef base::Callback<void(
- const ProxyInfo& proxy_info)> BeforeProxyHeadersSentCallback;
+ const ProxyInfo& proxy_info,
+ HttpRequestHeaders* request_headers)> BeforeProxyHeadersSentCallback;
// Stops any pending IO and destroys the transaction object.
virtual ~HttpTransaction() {}
@@ -36,9 +36,11 @@ class NET_EXPORT_PRIVATE HttpTransaction {
// Provides an opportunity to add proxy-specific request headers. Called after
// it is determined that a proxy is being used and before the request headers
- // are sent. |proxy_info| contains information about the proxy being used.
+ // are sent. |proxy_info| contains information about the proxy being used,
+ // and additional headers may be added to |request_headers|.
typedef base::Callback<void(